// rf95_client.pde
// -*- mode: C++ -*-
// Example sketch showing how to create a simple messageing client
// with the RH_RF95 class. RH_RF95 class does not provide for addressing or
// reliability, so you should only use RH_RF95 if you do not need the higher
// level messaging abilities.
// It is designed to work with the other example rf95_server
// Tested with Anarduino MiniWirelessLoRa, Rocket Scream Mini Ultra Pro with
// the RFM95W, Adafruit Feather M0 with RFM95

#include <SPI.h>
#include <RH_RF95.h>

// Singleton instance of the radio driver
RH_RF95 rf95(10, 2);

int led = 7; // do not use SPI pins

void setup()
{
  pinMode(led, OUTPUT);

  Serial.begin(9600);
  while (!Serial) ; // Wait for serial port to be available

  Serial.println("Client starting");

  if (!rf95.init())
  {
    Serial.println("rf95().init failed");
    while (true) ;
  }
  Serial.println("rf95.init() ok");

  // Defaults after init are 434.0MHz, 13dBm, Bw = 125 kHz, 
  // Cr = 4/5, Sf = 128chips/symbol, CRC on

  rf95.setFrequency(868.1);

  delay(100);
}

void loop()
{
  digitalWrite(led, HIGH);

  Serial.println("Sending to rf95_server");

  uint8_t data[] = "Hello World!";

  rf95.send(data, sizeof(data));
  rf95.waitPacketSent();

  Serial.println("Packet sent");

  // Now wait for a reply
  uint8_t buf[RH_RF95_MAX_MESSAGE_LEN];
  uint8_t len = sizeof(buf);

  if (rf95.waitAvailableTimeout(3000))
  {
    // Should be a reply message for us now
    if (rf95.recv(buf, &len))
    {
      Serial.print("got reply: ");
      Serial.println((char*)buf);
      //Serial.print("RSSI: ");
      //Serial.println(rf95.lastRssi(), DEC);
    }
    else
    {
      Serial.println("rf95.recv() from server failed");
    }
  }
  else
  {
    Serial.println("Timeout. No reply, is rf95_server running?");
  }

  digitalWrite(led, LOW);
  delay(400);
}


